@@ -8,18 +8,18 @@ from .dataclass_widget import (DataclassWidget, StackedDataclassWidget,
 
 
 __all__ = [
-    "type2Widget",
-    "BoolCheckBox",
-    "MISSING",
-    "EmptyIntValidator",
-    "IntLineEdit",
-    "EmptyFloatValidator",
-    "FloatLineEdit",
-    "StrLineEdit",
-    "TupleGroupBox",
-    "EnumComboBox",
+    'type2Widget',
+    'BoolCheckBox',
+    'MISSING',
+    'EmptyIntValidator',
+    'IntLineEdit',
+    'EmptyFloatValidator',
+    'FloatLineEdit',
+    'StrLineEdit',
+    'TupleGroupBox',
+    'EnumComboBox',
 
-    "DataclassWidget",
-    "StackedDataclassWidget",
-    "TabDataclassWidget",
+    'DataclassWidget',
+    'StackedDataclassWidget',
+    'TabDataclassWidget',
 ]
