@@ -2,15 +2,16 @@ import dataclasses
 from PySide6.QtCore import Signal
 from PySide6.QtWidgets import (QWidget, QGroupBox, QVBoxLayout, QStackedWidget,
     QTabWidget, QSizePolicy)
-from typing import Dict, Union, Optional, get_type_hints, Any
+from typing import Dict, Optional, get_type_hints, Any, Type
 
 from .datawidgets import type2Widget
+from .typing import DataclassProtocol
 
 
 __all__ = [
-    "DataclassWidget",
-    "StackedDataclassWidget",
-    "TabDataclassWidget",
+    'DataclassWidget',
+    'StackedDataclassWidget',
+    'TabDataclassWidget',
 ]
 
 
@@ -31,16 +32,21 @@ class DataclassWidget(QGroupBox):
     to :meth:`fromDataclass` class method. The class searches for
     ``Qt_typehint`` metadata from each field to determine the subwidget
     type. If ``Qt_typehint`` does not exist, type of the field is used
-    as a fallback.
+    as a fallback. Dataclass type used to construct the instance can be
+    retrieved by :meth:`dataclasType`.
 
     :meth:`dataValue` constructs and returns the dataclass instance from
-    the current data of the widgets. If the field has ``Qt_converter``
-    metadata, it is used to convert the widget data to field value.
+    the current data of the widgets. If field of :meth:`dataclasType`
+    has ``fromQt_converter`` metadata, it is used to convert the widget
+    data to field value.
 
     :meth:`setDataValue` updates the current states of the widgets with
-    dataclass instance. Whenever the data from subwidget is changed,
-    :attr:`dataValueChanged` emits the entire new dataclass instance if
-    all values are valid.
+    dataclass instance. If field of :meth:`dataclasType` has
+    ``toQt_converter`` metadata, it is used to convert the fied value
+    to widget data.
+
+    Whenever the data from subwidget is changed and values are all set,
+    :attr:`dataValueChanged` emits the entire new dataclass instance.
 
     Subclass may redefine :meth:`field2Widget` method to change how the
     subwidgets are constructed by the field. Every subwidget must have
@@ -62,7 +68,7 @@ class DataclassWidget(QGroupBox):
     >>> @dataclass
     ... class DataClass1:
     ...     a: Union[int, str] = field(metadata=dict(Qt_typehint=str))
-    ...     b: str = field(metadata=dict(Qt_converter=asUpper))
+    ...     b: str = field(metadata=dict(fromQt_converter=asUpper))
     >>> @dataclass
     ... class DataClass2:
     ...     x: int
@@ -79,19 +85,14 @@ class DataclassWidget(QGroupBox):
     dataValueChanged = Signal(object)
 
     @classmethod
-    def fromDataclass(cls, datacls: type) -> "DataclassWidget":
+    def fromDataclass(cls, datacls: Type[DataclassProtocol]) \
+                     -> 'DataclassWidget':
         """
         Construct the widget using the fields from the dataclass.
 
         If the field has ``Qt_typehint`` metadata, use its value to
         construct the widget. If not, use `Field.type` as a fallback.
 
-        Parameters
-        ==========
-
-        datacls
-            Dataclass type object
-
         """
         obj = cls()
         obj._dataclass_type = datacls
@@ -131,7 +132,7 @@ class DataclassWidget(QGroupBox):
 
         return widget
 
-    def dataclassType(self) -> type:
+    def dataclassType(self) -> Type[DataclassProtocol]:
         """Dataclass type which is used to construct *self*."""
         return self._dataclass_type
 
@@ -166,19 +167,14 @@ class DataclassWidget(QGroupBox):
         except (TypeError, ValueError):
             pass
 
-    def dataValue(self) -> Any:
+    def dataValue(self) -> DataclassProtocol:
         """
         Return the current state of widgets as dataclass instance.
 
-        Fields can have ``Qt_converter`` metadata whose value is a
-        unary function which takes the data value of subwidget. It is
-        used to construct the value for the field.
-
-        Returns
-        =======
-
-        data
-            Dataclass instance
+        Fields of :meth:`dataclassType` can have ``fromQt_converter``
+        metadata whose value is a unary function which takes the data
+        value of subwidget. It is used to construct the value for the
+        field.
 
         """
         widgets = self.widgets()
@@ -186,31 +182,32 @@ class DataclassWidget(QGroupBox):
         args = {}
         for f in dataclasses.fields(dcls):
             val = widgets[f.name].dataValue()
-            converter = f.metadata.get('Qt_converter', None)
+            converter = f.metadata.get('fromQt_converter', None)
             if converter is not None:
                 val = converter(val)
             args[f.name] = val
         data = dcls(**args)
         return data
 
-    def setDataValue(self, data: Any):
+    def setDataValue(self, data: DataclassProtocol):
         """
         Apply the dataclass instance to data widgets states.
 
-        Parameters
-        ==========
-
-        data
-            Dataclass instance or dict
+        Fields of :meth:`dataclassType` can have ``toQt_converter``
+        metadata whose value is a unary function which takes the field
+        value. Its return value is updated to the subwidget.
 
         """
-        for name, w in self.widgets().items():
-            if isinstance(data, dict):
-                if not name in data.keys():
-                    continue
-                val = data[name]
-            else:
-                val = getattr(data, name)
+        widgets = self.widgets()
+        dcls = self.dataclassType()
+
+        for f in dataclasses.fields(dcls):
+            val = getattr(data, f.name)
+            converter = f.metadata.get('toQt_converter', None)
+            if converter is not None:
+                val = converter(val)
+
+            w = widgets[f.name]
             w.setDataValue(val)
 
 
@@ -219,8 +216,8 @@ class StackedDataclassWidget(QStackedWidget):
     Stacked dataclass widgets.
 
     Use :meth:`addDataclass` to construct and add the widget for the
-    dataclass. Use :meth:`indexOf` to get the index of the widget for
-    giten dataclass.
+    dataclass. Use :meth:`indexOfDataclass` to get the index of the
+    widget for giten dataclass.
 
     If data value of any dataclass widget is changed,
     :attr:`dataValueChanged` signal emits the new value.
@@ -251,7 +248,7 @@ class StackedDataclassWidget(QStackedWidget):
     def __init__(self, parent=None):
         super().__init__(parent)
 
-        self._dataclasses: Dict[type, int] = {}
+        self._dataclasses: Dict[Type[DataclassProtocol], int] = {}
 
     def addWidget(self, w: QWidget):
         # force size policy to make ignore the size of hidden widget
@@ -294,7 +291,9 @@ class StackedDataclassWidget(QStackedWidget):
         super().setCurrentWidget(w)
         self.adjustSize()
 
-    def addDataclass(self, dcls: type, name: Optional[str] = None):
+    def addDataclass(self,
+                     dcls: Type[DataclassProtocol],
+                     name: Optional[str] = None):
         """Construct and add the :class:`DataclassWidget`"""
         if name is None:
             name = dcls.__name__
@@ -304,18 +303,9 @@ class StackedDataclassWidget(QStackedWidget):
         self._dataclasses[dcls] = self.indexOf(widget)
         widget.dataValueChanged.connect(self.emitDataValueChanged)
 
-    def indexOf(self, arg__1: Union[type, QWidget]) -> int:
-        """
-        Returns the index of the given dataclass or ``widget``. Return
-        -1 if it not exists in ``StackedDataclassWidget``.
-        """
-        if dataclasses.is_dataclass(arg__1):
-            if not isinstance(arg__1, type):
-                dcls = type(arg__1)
-            else:
-                dcls = arg__1
-            return self._dataclasses.get(dcls, -1)
-        return super().indexOf(arg__1)
+    def indexOfDataclass(self, dcls: Type[DataclassProtocol]) -> int:
+        """Returns the index of the widget for *dcls*."""
+        return self._dataclasses.get(dcls, -1)
 
     def emitDataValueChanged(self):
         try:
@@ -330,7 +320,7 @@ class TabDataclassWidget(QTabWidget):
     Tabbed dataclass widgets.
 
     Use :meth:`addDataclass` to construct and add the widget for the
-    dataclass. Use :meth:`indexOf` to get the index of the widget for
+    dataclass. Use :meth:`indexOfDataclass` to get the index of the widget for
     giten dataclass.
 
     If data value of any dataclass widget is changed,
@@ -352,8 +342,8 @@ class TabDataclassWidget(QTabWidget):
     >>> def runGUI():
     ...     app = QApplication(sys.argv)
     ...     widget = TabDataclassWidget()
-    ...     widget.addDataclass(DataClass1, "data1")
-    ...     widget.addDataclass(DataClass2, "data2")
+    ...     widget.addDataclass(DataClass1, 'data1')
+    ...     widget.addDataclass(DataClass2, 'data2')
     ...     widget.show()
     ...     app.exec()
     ...     app.quit()
@@ -365,7 +355,7 @@ class TabDataclassWidget(QTabWidget):
     def __init__(self, parent=None):
         super().__init__(parent)
 
-        self._dataclasses: Dict[type, int] = {}
+        self._dataclasses: Dict[Type[DataclassProtocol], int] = {}
 
     def addTab(self, widget: QWidget, *args):
         # force size policy to make ignore the size of hidden widget
@@ -408,25 +398,16 @@ class TabDataclassWidget(QTabWidget):
         super().setCurrentWidget(w)
         self.adjustSize()
 
-    def addDataclass(self, dcls: type, label: str):
+    def addDataclass(self, dcls: Type[DataclassProtocol], label: str):
         """Construct and add the :class:`DataclassWidget`"""
         widget = DataclassWidget.fromDataclass(dcls)
         self.addTab(widget, label)
         self._dataclasses[dcls] = self.indexOf(widget)
         widget.dataValueChanged.connect(self.emitDataValueChanged)
 
-    def indexOf(self, arg__1: Union[type, QWidget]) -> int:
-        """
-        Returns the index of the given dataclass or ``widget``. Return
-        -1 if it not exists in ``TabDataclassWidget``.
-        """
-        if dataclasses.is_dataclass(arg__1):
-            if not isinstance(arg__1, type):
-                dcls = type(arg__1)
-            else:
-                dcls = arg__1
-            return self._dataclasses.get(dcls, -1)
-        return super().indexOf(arg__1)
+    def indexOfDataclass(self, dcls: Type[DataclassProtocol]) -> int:
+        """Returns the index of the widget for *dcls*."""
+        return self._dataclasses.get(dcls, -1)
 
     def emitDataValueChanged(self):
         try:
