@@ -29,7 +29,7 @@ def dclswidget(qtbot):
         bool3: bool = False
         int2: int = 42
         float2: float = 4.2
-        str2: str = "foo"
+        str2: str = 'foo'
         Tuple3: Tuple[bool, int] = (True, 1)
         Tuple4: Tuple[bool, Tuple[int]] = (False, (2,))
         my_enum2: MyEnum = MyEnum.y
@@ -60,94 +60,94 @@ def nested_dcw(qtbot):
 
 def test_DataclassWidget_construction(qtbot, dclswidget):
 
-    widget_bool1 = dclswidget.widgets()["bool1"]
+    widget_bool1 = dclswidget.widgets()['bool1']
     assert not widget_bool1.isChecked()
-    assert widget_bool1.text() == "bool1"
+    assert widget_bool1.text() == 'bool1'
 
-    widget_int1 = dclswidget.widgets()["int1"]
-    assert widget_int1.placeholderText() == "int1"
-    assert widget_int1.text() == ""
+    widget_int1 = dclswidget.widgets()['int1']
+    assert widget_int1.placeholderText() == 'int1'
+    assert widget_int1.text() == ''
 
-    widget_float1 = dclswidget.widgets()["float1"]
-    assert widget_float1.placeholderText() == "float1"
-    assert widget_float1.text() == ""
+    widget_float1 = dclswidget.widgets()['float1']
+    assert widget_float1.placeholderText() == 'float1'
+    assert widget_float1.text() == ''
 
-    widget_str1 = dclswidget.widgets()["str1"]
-    assert widget_str1.placeholderText() == "str1"
-    assert widget_str1.text() == ""
+    widget_str1 = dclswidget.widgets()['str1']
+    assert widget_str1.placeholderText() == 'str1'
+    assert widget_str1.text() == ''
 
-    widget_Tuple1 = dclswidget.widgets()["Tuple1"]
-    assert widget_Tuple1.title() == "Tuple1"
+    widget_Tuple1 = dclswidget.widgets()['Tuple1']
+    assert widget_Tuple1.title() == 'Tuple1'
     assert not widget_Tuple1.widgets()[0].isChecked()
-    assert widget_Tuple1.widgets()[1].text() == ""
+    assert widget_Tuple1.widgets()[1].text() == ''
 
-    widget_Tuple2 = dclswidget.widgets()["Tuple2"]
+    widget_Tuple2 = dclswidget.widgets()['Tuple2']
     assert not widget_Tuple2.widgets()[0].isChecked()
-    assert widget_Tuple2.widgets()[1].widgets()[0].text() == ""
+    assert widget_Tuple2.widgets()[1].widgets()[0].text() == ''
 
-    widget_str1 = dclswidget.widgets()["my_enum1"]
-    assert widget_str1.placeholderText() == "my_enum1"
+    widget_str1 = dclswidget.widgets()['my_enum1']
+    assert widget_str1.placeholderText() == 'my_enum1'
     assert widget_str1.currentIndex() == -1
     assert widget_str1.dataValue() == MyEnum.x
 
-    widget_bool2 = dclswidget.widgets()["bool2"]
+    widget_bool2 = dclswidget.widgets()['bool2']
     assert widget_bool2.isChecked()
 
-    widget_bool3 = dclswidget.widgets()["bool3"]
+    widget_bool3 = dclswidget.widgets()['bool3']
     assert not widget_bool3.isChecked()
 
-    widget_int2 = dclswidget.widgets()["int2"]
-    assert widget_int2.text() == "42"
+    widget_int2 = dclswidget.widgets()['int2']
+    assert widget_int2.text() == '42'
 
-    widget_float2 = dclswidget.widgets()["float2"]
-    assert widget_float2.text() == "4.2"
+    widget_float2 = dclswidget.widgets()['float2']
+    assert widget_float2.text() == '4.2'
 
-    widget_str2 = dclswidget.widgets()["str2"]
-    assert widget_str2.text() == "foo"
+    widget_str2 = dclswidget.widgets()['str2']
+    assert widget_str2.text() == 'foo'
 
-    widget_Tuple3 = dclswidget.widgets()["Tuple3"]
+    widget_Tuple3 = dclswidget.widgets()['Tuple3']
     assert widget_Tuple3.widgets()[0].isChecked()
-    assert widget_Tuple3.widgets()[1].text() == "1"
+    assert widget_Tuple3.widgets()[1].text() == '1'
 
-    widget_Tuple4 = dclswidget.widgets()["Tuple4"]
+    widget_Tuple4 = dclswidget.widgets()['Tuple4']
     assert not widget_Tuple4.widgets()[0].isChecked()
-    assert widget_Tuple4.widgets()[1].widgets()[0].text() == "2"
+    assert widget_Tuple4.widgets()[1].widgets()[0].text() == '2'
 
-    widget_str1 = dclswidget.widgets()["my_enum2"]
-    assert widget_str1.placeholderText() == "my_enum2"
+    widget_str1 = dclswidget.widgets()['my_enum2']
+    assert widget_str1.placeholderText() == 'my_enum2'
     assert widget_str1.currentIndex() == 1
     assert widget_str1.dataValue() == MyEnum.y
 
 
 def test_nested_DataclassWidget_construction(qtbot, nested_dcw):
-    widget_dcls2 = nested_dcw.widgets()["b"]
-    widget_dcls1 = widget_dcls2.widgets()["y"]
+    widget_dcls2 = nested_dcw.widgets()['b']
+    widget_dcls1 = widget_dcls2.widgets()['y']
 
-    assert widget_dcls1.dataName() == "y"
-    assert widget_dcls2.dataName() == "b"
+    assert widget_dcls1.dataName() == 'y'
+    assert widget_dcls2.dataName() == 'b'
 
 
 def test_DataclassWidget_dataValueChanged(qtbot, dclswidget):
     # signal is not emitted until all values are valid
     with qtbot.assertNotEmitted(dclswidget.dataValueChanged):
-        dclswidget.widgets()["bool1"].setChecked(True)
+        dclswidget.widgets()['bool1'].setChecked(True)
     with qtbot.assertNotEmitted(dclswidget.dataValueChanged):
-        widget = dclswidget.widgets()["int1"]
-        widget.setText("42")
+        widget = dclswidget.widgets()['int1']
+        widget.setText('42')
         qtbot.keyPress(widget, Qt.Key_Return)
     with qtbot.assertNotEmitted(dclswidget.dataValueChanged):
-        widget = dclswidget.widgets()["float1"]
-        widget.setText("4.2")
+        widget = dclswidget.widgets()['float1']
+        widget.setText('4.2')
         qtbot.keyPress(widget, Qt.Key_Return)
     with qtbot.assertNotEmitted(dclswidget.dataValueChanged):
-        widget = dclswidget.widgets()["str1"]
-        widget.setText("foo")
+        widget = dclswidget.widgets()['str1']
+        widget.setText('foo')
         qtbot.keyPress(widget, Qt.Key_Return)
     with qtbot.assertNotEmitted(dclswidget.dataValueChanged):
-        dclswidget.widgets()["Tuple1"].widgets()[0].setChecked(True)
+        dclswidget.widgets()['Tuple1'].widgets()[0].setChecked(True)
     with qtbot.assertNotEmitted(dclswidget.dataValueChanged):
-        widget = dclswidget.widgets()["Tuple1"].widgets()[1]
-        widget.setText("42")
+        widget = dclswidget.widgets()['Tuple1'].widgets()[1]
+        widget.setText('42')
         qtbot.keyPress(widget, Qt.Key_Return)
 
     # now, signal is emitted
@@ -155,54 +155,54 @@ def test_DataclassWidget_dataValueChanged(qtbot, dclswidget):
     with qtbot.waitSignal(dclswidget.dataValueChanged,
                           raising=True,
                           check_params_cb=check):
-        widget = dclswidget.widgets()["Tuple2"].widgets()[1].widgets()[0]
-        widget.setText("42")
+        widget = dclswidget.widgets()['Tuple2'].widgets()[1].widgets()[0]
+        widget.setText('42')
         qtbot.keyPress(widget, Qt.Key_Return)
 
 
 def test_nested_DataclassWidget_dataValueChanged(qtbot, nested_dcw):
-    widget_dcls2 = nested_dcw.widgets()["b"]
-    widget_dcls1 = widget_dcls2.widgets()["y"]
+    widget_dcls2 = nested_dcw.widgets()['b']
+    widget_dcls1 = widget_dcls2.widgets()['y']
 
     with qtbot.assertNotEmitted(nested_dcw.dataValueChanged):
-        widget = widget_dcls1.widgets()["z"]
-        widget.setText("10")
+        widget = widget_dcls1.widgets()['z']
+        widget.setText('10')
         qtbot.keyPress(widget, Qt.Key_Return)
 
     check = lambda x: x == nested_dcw.dataValue()
     with qtbot.waitSignal(nested_dcw.dataValueChanged,
                           raising=True,
                           check_params_cb=check):
-        widget = widget_dcls2.widgets()["x"]
-        widget.setText("10")
+        widget = widget_dcls2.widgets()['x']
+        widget.setText('10')
         qtbot.keyPress(widget, Qt.Key_Return)
 
 
 def test_DataclassWidget_dataValue(qtbot, dclswidget):
     dclstype = dclswidget.dataclassType()
 
-    dclswidget.widgets()["bool1"].setChecked(True)
-    widget = dclswidget.widgets()["int1"]
-    widget.setText("1")
+    dclswidget.widgets()['bool1'].setChecked(True)
+    widget = dclswidget.widgets()['int1']
+    widget.setText('1')
     qtbot.keyPress(widget, Qt.Key_Return)
-    widget = dclswidget.widgets()["float1"]
-    widget.setText("2.3")
+    widget = dclswidget.widgets()['float1']
+    widget.setText('2.3')
     qtbot.keyPress(widget, Qt.Key_Return)
-    widget = dclswidget.widgets()["str1"]
-    widget.setText("foo")
+    widget = dclswidget.widgets()['str1']
+    widget.setText('foo')
     qtbot.keyPress(widget, Qt.Key_Return)
-    dclswidget.widgets()["Tuple1"].widgets()[0].setChecked(True)
-    widget = dclswidget.widgets()["Tuple1"].widgets()[1]
-    widget.setText("4")
+    dclswidget.widgets()['Tuple1'].widgets()[0].setChecked(True)
+    widget = dclswidget.widgets()['Tuple1'].widgets()[1]
+    widget.setText('4')
     qtbot.keyPress(widget, Qt.Key_Return)
-    widget = dclswidget.widgets()["Tuple2"].widgets()[1].widgets()[0]
-    widget.setText("5")
+    widget = dclswidget.widgets()['Tuple2'].widgets()[1].widgets()[0]
+    widget.setText('5')
     qtbot.keyPress(widget, Qt.Key_Return)
 
     assert dclswidget.dataValue() == dclstype(bool1=True,
                                               int1=1,
                                               float1=2.3,
-                                              str1="foo",
+                                              str1='foo',
                                               Tuple1=(True, 4),
                                               Tuple2=(False, (5,)),
                                               my_enum1=MyEnum.x)
@@ -210,17 +210,17 @@ def test_DataclassWidget_dataValue(qtbot, dclswidget):
 
 def test_nested_DataclassWidget_dataValue(qtbot, nested_dcw):
     dcls3 = nested_dcw.dataclassType()
-    widget_dcls2 = nested_dcw.widgets()["b"]
+    widget_dcls2 = nested_dcw.widgets()['b']
     dcls2 = widget_dcls2.dataclassType()
-    widget_dcls1 = widget_dcls2.widgets()["y"]
+    widget_dcls1 = widget_dcls2.widgets()['y']
     dcls1 = widget_dcls1.dataclassType()
 
-    widget = widget_dcls1.widgets()["z"]
-    widget.setText("1")
+    widget = widget_dcls1.widgets()['z']
+    widget.setText('1')
     qtbot.keyPress(widget, Qt.Key_Return)
 
-    widget = widget_dcls2.widgets()["x"]
-    widget.setText("2")
+    widget = widget_dcls2.widgets()['x']
+    widget.setText('2')
     qtbot.keyPress(widget, Qt.Key_Return)
 
     assert nested_dcw.dataValue() == dcls3(a=False, b=dcls2(x=2, y=dcls1(z=1)))
@@ -230,7 +230,7 @@ def test_DataclassWidget_setDataValue(qtbot, dclswidget):
     dc = dclswidget.dataclassType()(bool1=True,
                                     int1=42,
                                     float1=4.2,
-                                    str1="foo",
+                                    str1='foo',
                                     Tuple1=(False, 0),
                                     Tuple2=(False, (0,)),
                                     my_enum1=MyEnum.y)
@@ -239,24 +239,11 @@ def test_DataclassWidget_setDataValue(qtbot, dclswidget):
     assert dclswidget.dataValue() == dc
 
 
-def test_DataclassWidget_setDataValue_dict(qtbot, dclswidget):
-    dc = dclswidget.dataclassType()(bool1=True,
-                                    int1=42,
-                                    float1=4.2,
-                                    str1="foo",
-                                    Tuple1=(False, 0),
-                                    Tuple2=(False, (0,)),
-                                    my_enum1=MyEnum.y)
-
-    dclswidget.setDataValue(dataclasses.asdict(dc))
-    assert dclswidget.dataValue() == dc
-
-
 def test_nested_DataclassWidget_setDataValue(qtbot, nested_dcw):
     dcls3 = nested_dcw.dataclassType()
-    widget_dcls2 = nested_dcw.widgets()["b"]
+    widget_dcls2 = nested_dcw.widgets()['b']
     dcls2 = widget_dcls2.dataclassType()
-    widget_dcls1 = widget_dcls2.widgets()["y"]
+    widget_dcls1 = widget_dcls2.widgets()['y']
     dcls1 = widget_dcls1.dataclassType()
 
     dc = dcls3(a=True, b=dcls2(x=-1, y=dcls1(z=100)))
@@ -264,37 +251,25 @@ def test_nested_DataclassWidget_setDataValue(qtbot, nested_dcw):
     assert nested_dcw.dataValue() == dc
 
 
-def test_nested_DataclassWidget_setDataValue_dict(qtbot, nested_dcw):
-    dcls3 = nested_dcw.dataclassType()
-    widget_dcls2 = nested_dcw.widgets()["b"]
-    dcls2 = widget_dcls2.dataclassType()
-    widget_dcls1 = widget_dcls2.widgets()["y"]
-    dcls1 = widget_dcls1.dataclassType()
-
-    dc = dcls3(a=True, b=dcls2(x=-1, y=dcls1(z=100)))
-    nested_dcw.setDataValue(dataclasses.asdict(dc))
-    assert nested_dcw.dataValue() == dc
-
-
 def test_DataclassWidget_str_annotation(qtbot):
 
     @dataclasses.dataclass
     class A:
-        x: "int"
+        x: 'int'
     @dataclasses.dataclass
     class B(A):
-        y: "float"
+        y: 'float'
     @dataclasses.dataclass
     class C(B):
-        z: "bool"
+        z: 'bool'
 
     widgetA = DataclassWidget.fromDataclass(A)
     widgetB = DataclassWidget.fromDataclass(B)
     widgetC = DataclassWidget.fromDataclass(C)
 
-    assert isinstance(widgetA.widgets()["x"], IntLineEdit)
-    assert isinstance(widgetB.widgets()["y"], FloatLineEdit)
-    assert isinstance(widgetC.widgets()["z"], BoolCheckBox)
+    assert isinstance(widgetA.widgets()['x'], IntLineEdit)
+    assert isinstance(widgetB.widgets()['y'], FloatLineEdit)
+    assert isinstance(widgetC.widgets()['z'], BoolCheckBox)
 
 
 @pytest.fixture
@@ -310,17 +285,17 @@ def stackedwidget(qtbot):
         c: int
     widget = StackedDataclassWidget()
     widget.addDataclass(Dataclass1)
-    widget.addDataclass(Dataclass2, "")
-    widget.addDataclass(Dataclass3, "foo")
+    widget.addDataclass(Dataclass2, '')
+    widget.addDataclass(Dataclass3, 'foo')
     return widget
 
 
 def test_StackedDataclassWidget(qtbot, stackedwidget):
     assert stackedwidget.count() == 3
 
-    assert stackedwidget.widget(0).dataName() == "Dataclass1"
-    assert stackedwidget.widget(1).dataName() == ""
-    assert stackedwidget.widget(2).dataName() == "foo"
+    assert stackedwidget.widget(0).dataName() == 'Dataclass1'
+    assert stackedwidget.widget(1).dataName() == ''
+    assert stackedwidget.widget(2).dataName() == 'foo'
 
     Dataclass1 = stackedwidget.widget(0).dataclassType()
     Dataclass2 = stackedwidget.widget(1).dataclassType()
@@ -328,10 +303,10 @@ def test_StackedDataclassWidget(qtbot, stackedwidget):
     @dataclasses.dataclass
     class OtherDataclass:
         pass
-    assert stackedwidget.indexOf(Dataclass1) == 0
-    assert stackedwidget.indexOf(Dataclass2) == 1
-    assert stackedwidget.indexOf(Dataclass3) == 2
-    assert stackedwidget.indexOf(OtherDataclass) == -1
+    assert stackedwidget.indexOfDataclass(Dataclass1) == 0
+    assert stackedwidget.indexOfDataclass(Dataclass2) == 1
+    assert stackedwidget.indexOfDataclass(Dataclass3) == 2
+    assert stackedwidget.indexOfDataclass(OtherDataclass) == -1
 
 
 def test_StackedDataclassWidget_dataValueChanged(qtbot, stackedwidget):
@@ -341,24 +316,24 @@ def test_StackedDataclassWidget_dataValueChanged(qtbot, stackedwidget):
     with qtbot.waitSignal(stackedwidget.dataValueChanged,
                           raising=True,
                           check_params_cb=check):
-        widget = stackedwidget.widget(0).widgets()["a"]
-        widget.setText("10")
+        widget = stackedwidget.widget(0).widgets()['a']
+        widget.setText('10')
         qtbot.keyPress(widget, Qt.Key_Return)
 
     stackedwidget.setCurrentIndex(1)
     with qtbot.waitSignal(stackedwidget.dataValueChanged,
                           raising=True,
                           check_params_cb=check):
-        widget = stackedwidget.widget(1).widgets()["b"]
-        widget.setText("10")
+        widget = stackedwidget.widget(1).widgets()['b']
+        widget.setText('10')
         qtbot.keyPress(widget, Qt.Key_Return)
 
     stackedwidget.setCurrentIndex(2)
     with qtbot.waitSignal(stackedwidget.dataValueChanged,
                           raising=True,
                           check_params_cb=check):
-        widget = stackedwidget.widget(2).widgets()["c"]
-        widget.setText("10")
+        widget = stackedwidget.widget(2).widgets()['c']
+        widget.setText('10')
         qtbot.keyPress(widget, Qt.Key_Return)
 
 
@@ -445,23 +420,23 @@ def tabwidget(qtbot):
     class Dataclass3:
         c: int
     widget = TabDataclassWidget()
-    widget.addDataclass(Dataclass1, "foo")
-    widget.addDataclass(Dataclass2, "bar")
-    widget.addDataclass(Dataclass3, "baz")
+    widget.addDataclass(Dataclass1, 'foo')
+    widget.addDataclass(Dataclass2, 'bar')
+    widget.addDataclass(Dataclass3, 'baz')
     return widget
 
 
 def test_TabdataclassWidget(qtbot, tabwidget):
     assert tabwidget.count() == 3
 
-    assert tabwidget.widget(0).dataName() == ""
-    assert tabwidget.widget(1).dataName() == ""
-    assert tabwidget.widget(2).dataName() == ""
+    assert tabwidget.widget(0).dataName() == ''
+    assert tabwidget.widget(1).dataName() == ''
+    assert tabwidget.widget(2).dataName() == ''
 
 
-    assert tabwidget.tabText(0) == "foo"
-    assert tabwidget.tabText(1) == "bar"
-    assert tabwidget.tabText(2) == "baz"
+    assert tabwidget.tabText(0) == 'foo'
+    assert tabwidget.tabText(1) == 'bar'
+    assert tabwidget.tabText(2) == 'baz'
 
     Dataclass1 = tabwidget.widget(0).dataclassType()
     Dataclass2 = tabwidget.widget(1).dataclassType()
@@ -469,10 +444,10 @@ def test_TabdataclassWidget(qtbot, tabwidget):
     @dataclasses.dataclass
     class OtherDataclass:
         pass
-    assert tabwidget.indexOf(Dataclass1) == 0
-    assert tabwidget.indexOf(Dataclass2) == 1
-    assert tabwidget.indexOf(Dataclass3) == 2
-    assert tabwidget.indexOf(OtherDataclass) == -1
+    assert tabwidget.indexOfDataclass(Dataclass1) == 0
+    assert tabwidget.indexOfDataclass(Dataclass2) == 1
+    assert tabwidget.indexOfDataclass(Dataclass3) == 2
+    assert tabwidget.indexOfDataclass(OtherDataclass) == -1
 
 
 def test_TabdataclassWidget_dataValueChanged(qtbot, tabwidget):
@@ -482,24 +457,24 @@ def test_TabdataclassWidget_dataValueChanged(qtbot, tabwidget):
     with qtbot.waitSignal(tabwidget.dataValueChanged,
                           raising=True,
                           check_params_cb=check):
-        widget = tabwidget.widget(0).widgets()["a"]
-        widget.setText("10")
+        widget = tabwidget.widget(0).widgets()['a']
+        widget.setText('10')
         qtbot.keyPress(widget, Qt.Key_Return)
 
     tabwidget.setCurrentIndex(1)
     with qtbot.waitSignal(tabwidget.dataValueChanged,
                           raising=True,
                           check_params_cb=check):
-        widget = tabwidget.widget(1).widgets()["b"]
-        widget.setText("10")
+        widget = tabwidget.widget(1).widgets()['b']
+        widget.setText('10')
         qtbot.keyPress(widget, Qt.Key_Return)
 
     tabwidget.setCurrentIndex(2)
     with qtbot.waitSignal(tabwidget.dataValueChanged,
                           raising=True,
                           check_params_cb=check):
-        widget = tabwidget.widget(2).widgets()["c"]
-        widget.setText("10")
+        widget = tabwidget.widget(2).widgets()['c']
+        widget.setText('10')
         qtbot.keyPress(widget, Qt.Key_Return)
 
 
@@ -585,7 +560,7 @@ def test_Qt_typehint(qtbot):
     assert isinstance(widget.widgets()['x'], BoolCheckBox)
 
 
-def test_Qt_converter(qtbot):
+def test_Qt_converters(qtbot):
     class MyObj:
         def __init__(self, x: int, y: int):
                 self.x = x
@@ -599,7 +574,8 @@ def test_Qt_converter(qtbot):
             a: MyObj = dataclasses.field(
                     metadata=dict(
                         Qt_typehint=Tuple[int, int],
-                        Qt_converter=lambda tup: MyObj(*tup)
+                        fromQt_converter=lambda tup: MyObj(*tup),
+                        toQt_converter=lambda obj: (obj.x, obj.y)
                     )
             )
 
@@ -611,3 +587,7 @@ def test_Qt_converter(qtbot):
     tuple_widget.widgets()[1].setText('2')
     assert tuple_widget.dataValue() == (1, 2)
     assert dclswidget.dataValue() == Dataclass(MyObj(1, 2))
+
+    dclswidget.setDataValue(Dataclass(MyObj(2, 3)))
+    assert tuple_widget.widgets()[0].text() == '2'
+    assert tuple_widget.widgets()[1].text() == '3'
